diff frontends/src/quick_frontend/quick_card_game.py @ 1009:d1084f7e56a5

quick_frontend: use of new logging system
author Goffi <goffi@goffi.org>
date Mon, 05 May 2014 18:58:34 +0200
parents 1fe00f0c9a91
children 75025461141f
line wrap: on
line diff
--- a/frontends/src/quick_frontend/quick_card_game.py	Mon May 05 18:58:34 2014 +0200
+++ b/frontends/src/quick_frontend/quick_card_game.py	Mon May 05 18:58:34 2014 +0200
@@ -17,7 +17,8 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from logging import debug, info, error
+from sat.core.log import getLogger
+log = getLogger(__name__)
 from sat.tools.jid  import JID
 
 
@@ -153,7 +154,7 @@
         elif phase == "ecart":
             self.state = "ecart"
         else:
             error ('INTERNAL ERROR: unmanaged game phase')
 
         for suit, value in played_cards:
             self.hand.append(self.cards[suit, value])
@@ -153,7 +154,7 @@
             self.state = "ecart"
         else:
-            error ('INTERNAL ERROR: unmanaged game phase')
+            log.error ('INTERNAL ERROR: unmanaged game phase')
 
         for suit, value in played_cards: